# tksheet [![PyPI version shields.io](https://img.shields.io/pypi/v/tksheet.svg)](https://pypi.python.org/pypi/tksheet/) ![python](https://img.shields.io/badge/python-3.6+-blue) [![License: MIT](https://img.shields.io/badge/License-MIT%20-blue.svg)](https://github.com/ragardner/tksheet/blob/master/LICENSE.txt) [![GitHub Release Date](https://img.shields.io/github/release-date-pre/ragardner/tksheet.svg)](https://github.com/ragardner/tksheet/releases) [![Downloads](https://img.shields.io/pypi/dm/tksheet.svg)](https://pypi.org/project/tksheet/)


Python tkinter table widget

```
pip install tksheet
```
```
pip install tksheet --upgrade
```

### Help
 - [Documentation](https://github.com/ragardner/tksheet/wiki)
 - [Changelog](https://github.com/ragardner/tksheet/blob/master/CHANGELOG.md)

### Features
 - Display and modify tabular data
 - Stores its display data as a Python list of lists, sublists being rows
 - Runs smoothly even with millions of rows/columns
 - Edit cells directly
 - Drag and drop columns and rows
 - Multiple line headers and rows
 - Expand row heights and column widths
 - Change fonts and font size
 - Change any colors in the sheet
 - Create an unlimited number of high performance dropdown and check boxes
 - Left `"w"`, Center `"center"` or Right `"e"` text alignment
 - Cell values can be any class with a `str` method

### Light Blue Theme

![alt text](https://i.imgur.com/ojU3IQi.jpeg)

### Dark Theme

![alt text](https://i.imgur.com/JeF9vJe.jpeg)